pub struct EntityEquivalentHashSet<K: EntityEquivalent + Hash>(/* private fields */);Expand description
A HashSet pre-configured to use EntityHash hashing.
Implementations
Sourceimpl<K: EntityEquivalent + Hash> EntityEquivalentHashSet<K>
impl<K: EntityEquivalent + Hash> EntityEquivalentHashSet<K>
Sourcepub const fn new() -> Self
pub const fn new() -> Self
Creates an empty EntityEquivalentHashSet.
Equivalent to HashSet::with_hasher(EntityHash).
Sourcepub fn with_capacity(n: usize) -> Self
pub fn with_capacity(n: usize) -> Self
Creates an empty EntityEquivalentHashSet with the specified capacity.
Equivalent to HashSet::with_capacity_and_hasher(n, EntityHash).
Sourcepub const fn from_hash_set(set: HashSet<K, EntityHash>) -> Self
pub const fn from_hash_set(set: HashSet<K, EntityHash>) -> Self
Constructs an EntityHashSet from an HashSet.
Sourcepub fn into_inner(self) -> HashSet<K, EntityHash>
pub fn into_inner(self) -> HashSet<K, EntityHash>
Returns the inner HashSet.
Sourcepub fn drain(&mut self) -> Drain<'_, K> ⓘ
pub fn drain(&mut self) -> Drain<'_, K> ⓘ
Clears the set, returning all elements in an iterator.
Equivalent to HashSet::drain.
Sourcepub fn iter(&self) -> Iter<'_, K> ⓘ
pub fn iter(&self) -> Iter<'_, K> ⓘ
An iterator visiting all elements in arbitrary order.
The iterator element type is &'a Entity.
Equivalent to HashSet::iter.
Sourcepub fn extract_if<F: FnMut(&K) -> bool>(&mut self, f: F) -> ExtractIf<'_, K, F> ⓘ
pub fn extract_if<F: FnMut(&K) -> bool>(&mut self, f: F) -> ExtractIf<'_, K, F> ⓘ
Drains elements which are true under the given predicate, and returns an iterator over the removed items.
Equivalent to HashSet::extract_if.
Methods from Deref<Target = HashSet<K, EntityHash>>
Sourcepub fn iter(&self) -> Iter<'_, T> ⓘ
pub fn iter(&self) -> Iter<'_, T> ⓘ
An iterator visiting all elements in arbitrary order.
The iterator element type is &'a T.
Refer to iter for further details.
Examples
let mut map = HashSet::new();
map.insert("foo");
map.insert("bar");
map.insert("baz");
for value in map.iter() {
// "foo", "bar", "baz"
// Note that the above order is not guaranteed
}Sourcepub fn drain(&mut self) -> Drain<'_, T> ⓘ
pub fn drain(&mut self) -> Drain<'_, T> ⓘ
Clears the set, returning all elements in an iterator.
Refer to drain for further details.
Examples
let mut map = HashSet::new();
map.insert("foo");
map.insert("bar");
map.insert("baz");
for value in map.drain() {
// "foo", "bar", "baz"
// Note that the above order is not guaranteed
}
assert!(map.is_empty());Sourcepub fn extract_if<F>(&mut self, f: F) -> ExtractIf<'_, T, F> ⓘ
pub fn extract_if<F>(&mut self, f: F) -> ExtractIf<'_, T, F> ⓘ
Drains elements which are true under the given predicate, and returns an iterator over the removed items.
Refer to extract_if for further details.
Examples
let mut map = HashSet::new();
map.insert("foo");
map.insert("bar");
map.insert("baz");
let extracted = map
.extract_if(|value| *value == "baz")
.collect::<Vec<_>>();
assert_eq!(map.len(), 2);
assert_eq!(extracted.len(), 1);Sourcepub fn hasher(&self) -> &S
pub fn hasher(&self) -> &S
Returns a reference to the set’s BuildHasher.
Refer to hasher for further details.
Sourcepub fn reserve(&mut self, additional: usize)
pub fn reserve(&mut self, additional: usize)
Reserves capacity for at least additional more elements to be inserted
in the HashSet. The collection may reserve more space to avoid
frequent reallocations.
Refer to reserve for further details.
Examples
let mut map = HashSet::with_capacity(5);
assert!(map.capacity() >= 5);
map.reserve(10);
assert!(map.capacity() - map.len() >= 10);Sourcepub fn try_reserve(&mut self, additional: usize) -> Result<(), TryReserveError>
pub fn try_reserve(&mut self, additional: usize) -> Result<(), TryReserveError>
Tries to reserve capacity for at least additional more elements to be inserted
in the given HashSet<K,V>. The collection may reserve more space to avoid
frequent reallocations.
Refer to try_reserve for further details.
Examples
let mut map = HashSet::with_capacity(5);
assert!(map.capacity() >= 5);
map.try_reserve(10).expect("Out of Memory!");
assert!(map.capacity() - map.len() >= 10);Sourcepub fn shrink_to_fit(&mut self)
pub fn shrink_to_fit(&mut self)
Shrinks the capacity of the set as much as possible. It will drop down as much as possible while maintaining the internal rules and possibly leaving some space in accordance with the resize policy.
Refer to shrink_to_fit for further details.
Examples
let mut map = HashSet::with_capacity(5);
map.insert("foo");
map.insert("bar");
map.insert("baz");
assert!(map.capacity() >= 5);
map.shrink_to_fit();
assert_eq!(map.capacity(), 3);Sourcepub fn shrink_to(&mut self, min_capacity: usize)
pub fn shrink_to(&mut self, min_capacity: usize)
Shrinks the capacity of the set with a lower limit. It will drop down no lower than the supplied limit while maintaining the internal rules and possibly leaving some space in accordance with the resize policy.
Refer to shrink_to for further details.
Sourcepub fn difference<'a>(
&'a self,
other: &'a HashSet<T, S>,
) -> Difference<'a, T, S> ⓘ
pub fn difference<'a>( &'a self, other: &'a HashSet<T, S>, ) -> Difference<'a, T, S> ⓘ
Visits the values representing the difference,
i.e., the values that are in self but not in other.
Refer to difference for further details.
Sourcepub fn symmetric_difference<'a>(
&'a self,
other: &'a HashSet<T, S>,
) -> SymmetricDifference<'a, T, S> ⓘ
pub fn symmetric_difference<'a>( &'a self, other: &'a HashSet<T, S>, ) -> SymmetricDifference<'a, T, S> ⓘ
Visits the values representing the symmetric difference,
i.e., the values that are in self or in other but not in both.
Refer to symmetric_difference for further details.
Sourcepub fn intersection<'a>(
&'a self,
other: &'a HashSet<T, S>,
) -> Intersection<'a, T, S> ⓘ
pub fn intersection<'a>( &'a self, other: &'a HashSet<T, S>, ) -> Intersection<'a, T, S> ⓘ
Visits the values representing the intersection,
i.e., the values that are both in self and other.
Refer to intersection for further details.
Sourcepub fn union<'a>(&'a self, other: &'a HashSet<T, S>) -> Union<'a, T, S> ⓘ
pub fn union<'a>(&'a self, other: &'a HashSet<T, S>) -> Union<'a, T, S> ⓘ
Visits the values representing the union,
i.e., all the values in self or other, without duplicates.
Refer to union for further details.
Sourcepub fn get_or_insert(&mut self, value: T) -> &T
pub fn get_or_insert(&mut self, value: T) -> &T
Inserts the given value into the set if it is not present, then
returns a reference to the value in the set.
Refer to get_or_insert for further details.
Examples
let mut map = HashSet::new();
assert_eq!(map.get_or_insert("foo"), &"foo");Sourcepub fn get_or_insert_with<Q, F>(&mut self, value: &Q, f: F) -> &T
pub fn get_or_insert_with<Q, F>(&mut self, value: &Q, f: F) -> &T
Inserts a value computed from f into the set if the given value is
not present, then returns a reference to the value in the set.
Refer to get_or_insert_with for further details.
Examples
let mut map = HashSet::new();
assert_eq!(map.get_or_insert_with(&"foo", |_| "foo"), &"foo");Sourcepub fn is_disjoint(&self, other: &HashSet<T, S>) -> bool
pub fn is_disjoint(&self, other: &HashSet<T, S>) -> bool
Returns true if self has no elements in common with other.
This is equivalent to checking for an empty intersection.
Refer to is_disjoint for further details.
Sourcepub fn is_subset(&self, other: &HashSet<T, S>) -> bool
pub fn is_subset(&self, other: &HashSet<T, S>) -> bool
Returns true if the set is a subset of another,
i.e., other contains at least all the values in self.
Refer to is_subset for further details.
Sourcepub fn is_superset(&self, other: &HashSet<T, S>) -> bool
pub fn is_superset(&self, other: &HashSet<T, S>) -> bool
Returns true if the set is a superset of another,
i.e., self contains at least all the values in other.
Refer to is_superset for further details.
Sourcepub fn allocation_size(&self) -> usize
pub fn allocation_size(&self) -> usize
Returns the total amount of memory allocated internally by the hash set, in bytes.
Refer to allocation_size for further details.
Examples
let mut map = HashSet::new();
assert_eq!(map.allocation_size(), 0);
map.insert("foo");
assert!(map.allocation_size() >= size_of::<&'static str>());Sourcepub unsafe fn insert_unique_unchecked(&mut self, value: T) -> &T
pub unsafe fn insert_unique_unchecked(&mut self, value: T) -> &T
Insert a value the set without checking if the value already exists in the set.
Refer to insert_unique_unchecked for further details.
Safety
This operation is safe if a value does not exist in the set.
However, if a value exists in the set already, the behavior is unspecified: this operation may panic, loop forever, or any following operation with the set may panic, loop forever or return arbitrary result.
That said, this operation (and following operations) are guaranteed to not violate memory safety.
However this operation is still unsafe because the resulting HashSet
may be passed to unsafe code which does expect the set to behave
correctly, and would cause unsoundness as a result.
Methods from Deref<Target = HashSet<T, S>>
Sourcepub fn capacity(&self) -> usize
pub fn capacity(&self) -> usize
Returns the number of elements the set can hold without reallocating.
Examples
use hashbrown::HashSet;
let set: HashSet<i32> = HashSet::with_capacity(100);
assert!(set.capacity() >= 100);Sourcepub fn iter(&self) -> Iter<'_, T> ⓘ
pub fn iter(&self) -> Iter<'_, T> ⓘ
An iterator visiting all elements in arbitrary order.
The iterator element type is &'a T.
Examples
use hashbrown::HashSet;
let mut set = HashSet::new();
set.insert("a");
set.insert("b");
// Will print in an arbitrary order.
for x in set.iter() {
println!("{}", x);
}Sourcepub fn len(&self) -> usize
pub fn len(&self) -> usize
Returns the number of elements in the set.
Examples
use hashbrown::HashSet;
let mut v = HashSet::new();
assert_eq!(v.len(), 0);
v.insert(1);
assert_eq!(v.len(), 1);Sourcepub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> bool
Returns true if the set contains no elements.
Examples
use hashbrown::HashSet;
let mut v = HashSet::new();
assert!(v.is_empty());
v.insert(1);
assert!(!v.is_empty());Sourcepub fn hasher(&self) -> &S
pub fn hasher(&self) -> &S
Returns a reference to the set’s BuildHasher.
Examples
use hashbrown::HashSet;
use hashbrown::DefaultHashBuilder;
let hasher = DefaultHashBuilder::default();
let set: HashSet<i32> = HashSet::with_hasher(hasher);
let hasher: &DefaultHashBuilder = set.hasher();Sourcepub fn difference<'a>(
&'a self,
other: &'a HashSet<T, S, A>,
) -> Difference<'a, T, S, A> ⓘ
pub fn difference<'a>( &'a self, other: &'a HashSet<T, S, A>, ) -> Difference<'a, T, S, A> ⓘ
Visits the values representing the difference,
i.e., the values that are in self but not in other.
Examples
use hashbrown::HashSet;
let a: HashSet<_> = [1, 2, 3].into_iter().collect();
let b: HashSet<_> = [4, 2, 3, 4].into_iter().collect();
// Can be seen as `a - b`.
for x in a.difference(&b) {
println!("{}", x); // Print 1
}
let diff: HashSet<_> = a.difference(&b).collect();
assert_eq!(diff, [1].iter().collect());
// Note that difference is not symmetric,
// and `b - a` means something else:
let diff: HashSet<_> = b.difference(&a).collect();
assert_eq!(diff, [4].iter().collect());Sourcepub fn symmetric_difference<'a>(
&'a self,
other: &'a HashSet<T, S, A>,
) -> SymmetricDifference<'a, T, S, A> ⓘ
pub fn symmetric_difference<'a>( &'a self, other: &'a HashSet<T, S, A>, ) -> SymmetricDifference<'a, T, S, A> ⓘ
Visits the values representing the symmetric difference,
i.e., the values that are in self or in other but not in both.
Examples
use hashbrown::HashSet;
let a: HashSet<_> = [1, 2, 3].into_iter().collect();
let b: HashSet<_> = [4, 2, 3, 4].into_iter().collect();
// Print 1, 4 in arbitrary order.
for x in a.symmetric_difference(&b) {
println!("{}", x);
}
let diff1: HashSet<_> = a.symmetric_difference(&b).collect();
let diff2: HashSet<_> = b.symmetric_difference(&a).collect();
assert_eq!(diff1, diff2);
assert_eq!(diff1, [1, 4].iter().collect());Sourcepub fn intersection<'a>(
&'a self,
other: &'a HashSet<T, S, A>,
) -> Intersection<'a, T, S, A> ⓘ
pub fn intersection<'a>( &'a self, other: &'a HashSet<T, S, A>, ) -> Intersection<'a, T, S, A> ⓘ
Visits the values representing the intersection,
i.e., the values that are both in self and other.
Examples
use hashbrown::HashSet;
let a: HashSet<_> = [1, 2, 3].into_iter().collect();
let b: HashSet<_> = [4, 2, 3, 4].into_iter().collect();
// Print 2, 3 in arbitrary order.
for x in a.intersection(&b) {
println!("{}", x);
}
let intersection: HashSet<_> = a.intersection(&b).collect();
assert_eq!(intersection, [2, 3].iter().collect());Sourcepub fn union<'a>(&'a self, other: &'a HashSet<T, S, A>) -> Union<'a, T, S, A> ⓘ
pub fn union<'a>(&'a self, other: &'a HashSet<T, S, A>) -> Union<'a, T, S, A> ⓘ
Visits the values representing the union,
i.e., all the values in self or other, without duplicates.
Examples
use hashbrown::HashSet;
let a: HashSet<_> = [1, 2, 3].into_iter().collect();
let b: HashSet<_> = [4, 2, 3, 4].into_iter().collect();
// Print 1, 2, 3, 4 in arbitrary order.
for x in a.union(&b) {
println!("{}", x);
}
let union: HashSet<_> = a.union(&b).collect();
assert_eq!(union, [1, 2, 3, 4].iter().collect());Sourcepub fn contains<Q>(&self, value: &Q) -> bool
pub fn contains<Q>(&self, value: &Q) -> bool
Returns true if the set contains a value.
The value may be any borrowed form of the set’s value type, but
Hash and Eq on the borrowed form must match those for
the value type.
Examples
use hashbrown::HashSet;
let set: HashSet<_> = [1, 2, 3].into_iter().collect();
assert_eq!(set.contains(&1), true);
assert_eq!(set.contains(&4), false);Sourcepub fn get<Q>(&self, value: &Q) -> Option<&T>
pub fn get<Q>(&self, value: &Q) -> Option<&T>
Returns a reference to the value in the set, if any, that is equal to the given value.
The value may be any borrowed form of the set’s value type, but
Hash and Eq on the borrowed form must match those for
the value type.
Examples
use hashbrown::HashSet;
let set: HashSet<_> = [1, 2, 3].into_iter().collect();
assert_eq!(set.get(&2), Some(&2));
assert_eq!(set.get(&4), None);Sourcepub fn is_disjoint(&self, other: &HashSet<T, S, A>) -> bool
pub fn is_disjoint(&self, other: &HashSet<T, S, A>) -> bool
Returns true if self has no elements in common with other.
This is equivalent to checking for an empty intersection.
Examples
use hashbrown::HashSet;
let a: HashSet<_> = [1, 2, 3].into_iter().collect();
let mut b = HashSet::new();
assert_eq!(a.is_disjoint(&b), true);
b.insert(4);
assert_eq!(a.is_disjoint(&b), true);
b.insert(1);
assert_eq!(a.is_disjoint(&b), false);Sourcepub fn is_subset(&self, other: &HashSet<T, S, A>) -> bool
pub fn is_subset(&self, other: &HashSet<T, S, A>) -> bool
Returns true if the set is a subset of another,
i.e., other contains at least all the values in self.
Examples
use hashbrown::HashSet;
let sup: HashSet<_> = [1, 2, 3].into_iter().collect();
let mut set = HashSet::new();
assert_eq!(set.is_subset(&sup), true);
set.insert(2);
assert_eq!(set.is_subset(&sup), true);
set.insert(4);
assert_eq!(set.is_subset(&sup), false);Sourcepub fn is_superset(&self, other: &HashSet<T, S, A>) -> bool
pub fn is_superset(&self, other: &HashSet<T, S, A>) -> bool
Returns true if the set is a superset of another,
i.e., self contains at least all the values in other.
Examples
use hashbrown::HashSet;
let sub: HashSet<_> = [1, 2].into_iter().collect();
let mut set = HashSet::new();
assert_eq!(set.is_superset(&sub), false);
set.insert(0);
set.insert(1);
assert_eq!(set.is_superset(&sub), false);
set.insert(2);
assert_eq!(set.is_superset(&sub), true);Sourcepub fn allocation_size(&self) -> usize
pub fn allocation_size(&self) -> usize
Returns the total amount of memory allocated internally by the hash set, in bytes.
The returned number is informational only. It is intended to be primarily used for memory profiling.